@@ -1,7 +1,7 @@
 # This is file ../spam/R/kronecker.R
 # This file is part of the spam package, 
 #      http://www.math.uzh.ch/furrer/software/spam/
-# written and maintained by Reinhard Furrer.
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
      
 
 
@@ -61,7 +61,7 @@ kronecker.spam <- function(X,Y,FUN = "*", make.dimnames = FALSE, ...)
                   entries=vector( "double", kronlen),
                   colindices=vector( "integer", kronlen),
                   rowpointers=vector( "integer",Xdim[1]*Ydim[1]+1),
-                  NAOK=!.Spam$safemode[3],DUP=FALSE,PACKAGE = "spam")
+                  NAOK=!.Spam$safemode[3],DUP=DUPFALSE,PACKAGE = "spam")
     slot(kronxy, "entries", check=FALSE) <-  z$entries
    }else {
     z <- .Fortran("kronecker",Xdim[1],Xentries,Xcol,Xrow,
@@ -69,7 +69,7 @@ kronecker.spam <- function(X,Y,FUN = "*", make.dimnames = FALSE, ...)
                   ent1=vector( "double",kronlen),ent2=vector( "double",kronlen),
                   colindices=vector( "integer",kronlen),
                   rowpointers=vector( "integer",Xdim[1]*Ydim[1]+1),
-                  NAOK=!.Spam$safemode[3],DUP=FALSE,PACKAGE = "spam")
+                  NAOK=!.Spam$safemode[3],DUP=DUPFALSE,PACKAGE = "spam")
     FUN <- match.fun(FUN)
     slot(kronxy, "entries", check=FALSE) <-  FUN(z$ent1,z$ent2,...)
     if (z$rowpointers[Xdim[1]*Ydim[1]+1]-1 < prod(Xdim,Ydim))
